(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     18594,        446]
NotebookOptionsPosition[     18302,        432]
NotebookOutlinePosition[     18642,        447]
CellTagsIndexPosition[     18599,        444]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 StyleBox["A GENERALIZED DESIGN METHOD FOR DIRECTIVITY PATTERNS OF SPHERICAL \
MICROPHONE ARRAYS", "Title",
  FontSize->16],
 "\n\n",
 StyleBox["Enzo De Sena, H\[UDoubleDot]seyin Hac\[DotlessI]habibo\:011flu and \
Zoran Cvetkovic\nDepartment of Informatics, King' s College London Strand, \n\
WC2R 2 LS, London, United Kingdom\n{e.desena | zoran.cvetkovic}@kcl.ac.uk\n\
huseyin@hacihabiboglu.org",
  Editable->False,
  Deletable->False],
 "\n\n\n\n",
 StyleBox["To execute the notebook, please evaluate the following block of \
code (Shift + enter)", "Section",
  FontSize->16],
 "\n\n"
}], "Input",
 CellChangeTimes->{
  3.4972218000398293`*^9, 3.497221835725978*^9, {3.49722193468237*^9, 
   3.497221935554351*^9}},
 FormatType->"TextForm"],

Cell[BoxData[
 RowBox[{
  RowBox[{"DynamicModule", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\[Lambda]", "=", "0.5"}], ",", 
      RowBox[{"\[Alpha]", "=", 
       RowBox[{"Pi", "/", "2"}]}], ",", 
      RowBox[{"\[Beta]", "=", "90"}]}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"\[CapitalGamma]", "[", 
       RowBox[{"\[Theta]_", ",", "a1_", ",", "a2_"}], "]"}], "=", 
      RowBox[{"1", "-", "a1", "-", "a2", "+", 
       RowBox[{"a1", " ", 
        RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "+", 
       RowBox[{"a2", " ", 
        RowBox[{
         RowBox[{"Cos", "[", "\[Theta]", "]"}], "^", "2"}]}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"\[CapitalGamma]1", "[", 
       RowBox[{"\[Theta]_", ",", "a1_", ",", "a2_"}], "]"}], "=", 
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{"\[CapitalGamma]", "[", 
         RowBox[{"\[Theta]", ",", "a1", ",", "a2"}], "]"}], ",", "\[Theta]"}],
        "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"\[CapitalPhi]1", "[", 
       RowBox[{"a1_", ",", "a2_", ",", "\[Alpha]_"}], "]"}], "=", 
      RowBox[{
       RowBox[{"Integrate", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"\[CapitalGamma]", "[", 
            RowBox[{"\[Theta]", ",", "a1", ",", "a2"}], "]"}], "^", "2"}], 
          RowBox[{"Sin", "[", "\[Theta]", "]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"\[Theta]", ",", "\[Alpha]", ",", "Pi"}], "}"}]}], "]"}], 
       "/", 
       RowBox[{"Integrate", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"\[CapitalGamma]", "[", 
            RowBox[{"\[Theta]", ",", "a1", ",", "a2"}], "]"}], "^", "2"}], 
          RowBox[{"Sin", "[", "\[Theta]", "]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"\[Theta]", ",", "0", ",", "\[Alpha]"}], "}"}]}], "]"}]}]}],
      ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"\[CapitalPhi]2", "[", 
       RowBox[{"a1_", ",", "a2_", ",", "\[Alpha]_"}], "]"}], "=", 
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"\[CapitalGamma]1", "[", 
           RowBox[{"\[Theta]", ",", "a1", ",", "a2"}], "]"}], "^", "2"}], 
         RowBox[{"Sin", "[", "\[Theta]", "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]", ",", "0", ",", "\[Alpha]"}], "}"}]}], "]"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"\[CapitalPhi]", "[", 
       RowBox[{"a1_", ",", "a2_", ",", "\[Lambda]_", ",", "\[Alpha]_"}], 
       "]"}], "=", 
      RowBox[{
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"\[CapitalPhi]1", "[", 
         RowBox[{"a1", ",", "a2", ",", "\[Alpha]"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", "\[Lambda]"}], ")"}], "  ", 
        RowBox[{"\[CapitalPhi]2", "[", 
         RowBox[{"a1", ",", "a2", ",", "\[Alpha]"}], "]"}]}]}]}], " ", ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"DirFactor", "[", 
       RowBox[{"a1_", ",", "a2_"}], "]"}], "=", 
      RowBox[{"2", "/", 
       RowBox[{"Integrate", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"\[CapitalGamma]", "[", 
            RowBox[{"\[Theta]", ",", "a1", ",", "a2"}], "]"}], "^", "2"}], 
          RowBox[{"Sin", "[", "\[Theta]", "]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"\[Theta]", ",", "0", ",", "Pi"}], "}"}]}], "]"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"LogF", "[", "\[CapitalGamma]_", "]"}], "=", 
      RowBox[{
       RowBox[{"UnitStep", "[", 
        RowBox[{
         RowBox[{"20", 
          RowBox[{"Log", "[", 
           RowBox[{"10", ",", 
            RowBox[{"Abs", "[", "\[CapitalGamma]", "]"}]}], "]"}]}], "+", 
         "40"}], "]"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"20", 
          RowBox[{"Log", "[", 
           RowBox[{"10", ",", 
            RowBox[{"Abs", "[", "\[CapitalGamma]", "]"}]}], "]"}]}], "+", 
         "40"}], ")"}]}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]",
      "\[IndentingNewLine]", 
     RowBox[{"Column", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Row", "[", 
         RowBox[{"{", 
          RowBox[{"Dynamic", "[", 
           RowBox[{
            RowBox[{"solution", "=", 
             RowBox[{
              RowBox[{"Minimize", "[", 
               RowBox[{
                RowBox[{"\[CapitalPhi]", "[", 
                 RowBox[{"a1", ",", "a2", ",", "\[Lambda]", ",", "\[Alpha]"}],
                  "]"}], ",", 
                RowBox[{"{", 
                 RowBox[{"a1", ",", "a2"}], "}"}]}], "]"}], "[", 
              RowBox[{"[", "2", "]"}], "]"}]}], ";", 
            RowBox[{"If", "[", " ", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"FindMaximum", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"\[CapitalGamma]", "[", 
                    RowBox[{"\[Theta]", ",", "a1", ",", "a2"}], "]"}], "/.", 
                   "solution"}], ",", "\[Theta]"}], "]"}], "[", 
                RowBox[{"[", "1", "]"}], "]"}], ">", "1"}], ",", 
              RowBox[{
               RowBox[{"solution", "=", 
                RowBox[{
                 RowBox[{"Minimize", "[", 
                  RowBox[{
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"\[CapitalPhi]", "[", 
                    RowBox[{
                    "a1", ",", "a2", ",", "\[Lambda]", ",", "\[Alpha]"}], 
                    "]"}], ",", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "a1"}], "-", 
                    RowBox[{"2", " ", "a2"}]}], "\[LessEqual]", "0"}]}], 
                    "}"}], ",", 
                   RowBox[{"{", 
                    RowBox[{"a1", ",", "a2"}], "}"}]}], "]"}], "[", 
                 RowBox[{"[", "2", "]"}], "]"}]}], ";"}]}], "]"}]}], "]"}], 
          "}"}], "]"}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"Panel", "[", 
         RowBox[{"Column", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Row", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Slider2D", "[", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"Dynamic", "[", "\[Alpha]", "]"}], ",", 
                   RowBox[{"Dynamic", "[", "\[Lambda]", "]"}]}], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"{", 
                    RowBox[{"0.000001", ",", "0"}], "}"}], ",", 
                   RowBox[{"{", 
                    RowBox[{"Pi", ",", "1"}], "}"}]}], "}"}], ",", 
                 RowBox[{"ImageSize", "\[Rule]", "Medium"}]}], "]"}], ",", 
               RowBox[{"Column", "[", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"Row", "[", 
                   RowBox[{"{", 
                    RowBox[{
                    "\"\<  Set\[VeryThinSpace] \[Lambda] here: \>\"", ",", 
                    RowBox[{"Control", "[", 
                    RowBox[{"{", 
                    RowBox[{"\[Lambda]", ",", "0", ",", "1"}], "}"}], "]"}], 
                    ",", "\"\<  Value of \[Lambda]: \>\"", ",", 
                    RowBox[{"Dynamic", "[", "\[Lambda]", "]"}]}], "}"}], 
                   "]"}], ",", 
                  RowBox[{"Row", "[", 
                   RowBox[{"{", 
                    RowBox[{
                    "\"\<  Set\[VeryThinSpace] \[Alpha] here: \>\"", ",", 
                    RowBox[{"Control", "[", 
                    RowBox[{"{", 
                    RowBox[{"\[Alpha]", ",", "0.000001", ",", "Pi"}], "}"}], 
                    "]"}], ",", "\"\<  Value of \[Alpha]: \>\"", ",", 
                    RowBox[{"Dynamic", "[", "\[Alpha]", "]"}]}], "}"}], 
                   "]"}]}], "}"}], "]"}]}], "}"}], "]"}], ",", 
            RowBox[{"Row", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Button", "[", 
                RowBox[{"\"\<Omnidirectional\>\"", ",", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"\[Lambda]", "=", "0"}], ",", 
                   RowBox[{"\[Alpha]", "=", "Pi"}]}], "}"}]}], "]"}], ",", 
               RowBox[{"Button", "[", 
                RowBox[{"\"\<Cardioid\>\"", ",", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"\[Lambda]", "=", "1"}], ",", 
                   RowBox[{"\[Alpha]", "=", "3.099072647094727"}]}], "}"}]}], 
                "]"}], ",", 
               RowBox[{"Button", "[", 
                RowBox[{"\"\<Supercardioid\>\"", ",", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"\[Lambda]", "=", "1"}], ",", 
                   RowBox[{"\[Alpha]", "=", 
                    RowBox[{"N", "[", 
                    RowBox[{"Pi", "/", "2"}], "]"}]}]}], "}"}]}], "]"}], ",", 
               
               RowBox[{"Button", "[", 
                RowBox[{"\"\<Hypercardioid\>\"", ",", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"\[Lambda]", "=", "1"}], ",", 
                   RowBox[{"\[Alpha]", "=", "0.000001"}]}], "}"}]}], "]"}]}], 
              "}"}], "]"}], ",", "\[IndentingNewLine]", 
            "\"\<_____________________________________________________________\
_____________________________________\>\"", ",", "\[IndentingNewLine]", 
            "\"\<\>\"", ",", "\[IndentingNewLine]", 
            RowBox[{"Row", "[", 
             RowBox[{"{", 
              RowBox[{"\"\<Coefficients: \>\"", ",", " ", 
               RowBox[{"Dynamic", "[", "solution", "]"}]}], "}"}], "]"}], ",",
             "\[IndentingNewLine]", 
            RowBox[{"Row", "[", 
             RowBox[{"{", 
              RowBox[{
              "\"\<Spherical harmonics coefficients: \>\"", ",", " ", 
               RowBox[{"Dynamic", "[", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"b0", "\[Rule]", 
                    RowBox[{
                    RowBox[{"-", 
                    FractionBox["2", "3"]}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "3"}], " ", 
                    SqrtBox["\[Pi]"]}], "+", 
                    RowBox[{"3", " ", "a1", " ", 
                    SqrtBox["\[Pi]"]}], "+", 
                    RowBox[{"2", " ", "a2", " ", 
                    SqrtBox["\[Pi]"]}]}], ")"}]}]}], ",", 
                    RowBox[{"b1", "\[Rule]", 
                    RowBox[{"2", " ", "a1", " ", 
                    SqrtBox[
                    FractionBox["\[Pi]", "3"]]}]}], ",", 
                    RowBox[{"b2", "\[Rule]", 
                    RowBox[{
                    FractionBox["4", "3"], " ", "a2", " ", 
                    SqrtBox[
                    FractionBox["\[Pi]", "5"]]}]}]}], "}"}], "}"}], "/.", 
                 "solution"}], "]"}]}], "}"}], "]"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"Row", "[", 
             RowBox[{"{", 
              RowBox[{"\"\<Front-back ratio: \>\"", ",", 
               RowBox[{"Dynamic", "[", " ", 
                RowBox[{"10", 
                 RowBox[{"Log", "[", 
                  RowBox[{"10", ",", 
                   RowBox[{"1", "/", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[CapitalPhi]1", "[", 
                    RowBox[{"a1", ",", "a2", ",", 
                    RowBox[{"Pi", "/", "2"}]}], "]"}], "/.", " ", 
                    "solution"}], ")"}]}]}], "]"}]}], "]"}]}], "}"}], "]"}], 
            ",", "\[IndentingNewLine]", 
            RowBox[{"Row", "[", 
             RowBox[{"{", 
              RowBox[{"\"\<Directivity index: \>\"", ",", 
               RowBox[{"Dynamic", "[", " ", 
                RowBox[{"10", 
                 RowBox[{"Log", "[", 
                  RowBox[{"10", ",", 
                   RowBox[{
                    RowBox[{"DirFactor", "[", 
                    RowBox[{"a1", ",", "a2"}], "]"}], "/.", " ", 
                    "solution"}]}], "]"}]}], "]"}]}], "}"}], "]"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"Row", "[", 
             RowBox[{"{", 
              RowBox[{"\"\<The level at \>\"", ",", 
               RowBox[{"Slider", "[", 
                RowBox[{
                 RowBox[{"Dynamic", "[", "\[Beta]", "]"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"0", ",", "180"}], "}"}], ",", 
                 RowBox[{"ImageSize", "\[Rule]", "Small"}]}], "]"}], ",", 
               "\"\< \>\"", ",", " ", 
               RowBox[{"Dynamic", "[", "\[Beta]", "]"}], ",", 
               "\"\< degrees is: \>\"", ",", 
               RowBox[{"Dynamic", "[", 
                RowBox[{"20", 
                 RowBox[{"Log", "[", 
                  RowBox[{"10", ",", 
                   RowBox[{"Abs", "[", 
                    RowBox[{
                    RowBox[{"\[CapitalGamma]", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[Beta]", "/", "180"}], "*", "Pi"}], ",", "a1", 
                    ",", "a2"}], "]"}], "/.", "solution"}], "]"}]}], "]"}]}], 
                "]"}]}], "}"}], "]"}], ",", "\[IndentingNewLine]", "\"\<\>\"",
             ",", "\[IndentingNewLine]", 
            "\"\<Amplitude plot on the left. The same plot with dB scale (the \
center is at <40dB) is on the right.\>\"", ",", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"Dynamic", "[", 
              RowBox[{"PolarPlot", "[", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"\[CapitalGamma]", "[", 
                    RowBox[{"\[Theta]", ",", "a1", ",", "a2"}], "]"}], "/.", 
                    "solution"}], "]"}], ",", "1"}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"\[Theta]", ",", "0", ",", 
                  RowBox[{"2", "Pi"}]}], "}"}], ",", 
                RowBox[{"ImageSize", "\[Rule]", "Medium"}], ",", 
                RowBox[{"PlotStyle", "\[Rule]", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"Directive", "[", 
                    RowBox[{"Thick", ",", "Blue"}], "]"}], ",", "Gray"}], 
                  "}"}]}]}], "]"}], "]"}], "\[IndentingNewLine]", 
             RowBox[{"Dynamic", "[", 
              RowBox[{"PolarPlot", "[", 
               RowBox[{
                RowBox[{"{", "\[IndentingNewLine]", 
                 RowBox[{
                  RowBox[{"LogF", "[", 
                   RowBox[{
                    RowBox[{"\[CapitalGamma]", "[", 
                    RowBox[{"\[Theta]", ",", "a1", ",", "a2"}], "]"}], "/.", 
                    "solution"}], "]"}], ",", "40"}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"\[Theta]", ",", "0", ",", 
                  RowBox[{"2", "Pi"}]}], "}"}], ",", 
                RowBox[{"ImageSize", "\[Rule]", "Medium"}], ",", 
                RowBox[{"PlotStyle", "\[Rule]", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"Directive", "[", 
                    RowBox[{"Thick", ",", "Blue"}], "]"}], ",", "Gray"}], 
                  "}"}]}]}], "]"}], "]"}]}]}], "}"}], "]"}], "]"}]}], "}"}], 
      "]"}]}]}], "]"}], "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.497090515079805*^9, 3.497090569120805*^9}, {
   3.497091090889357*^9, 3.4970911075355186`*^9}, {3.497091146477536*^9, 
   3.4970911468411913`*^9}, {3.4971640884330606`*^9, 3.497164120856448*^9}, {
   3.497164172022901*^9, 3.4971642131505938`*^9}, {3.497164251839501*^9, 
   3.497164258137253*^9}, {3.497164320615226*^9, 3.497164343572535*^9}, {
   3.497164432667471*^9, 3.497164441130286*^9}, {3.497164489205212*^9, 
   3.497164491394081*^9}, {3.4971645528745737`*^9, 3.49716457604105*^9}, 
   3.497164625100745*^9, 3.4971646631803493`*^9, 3.4971661567492647`*^9, {
   3.497166188412478*^9, 3.497166194886483*^9}, {3.497166230474901*^9, 
   3.4971662915095997`*^9}, {3.497166357141111*^9, 3.497166373822412*^9}, {
   3.497166414329027*^9, 3.497166582016519*^9}, {3.49716713135244*^9, 
   3.497167135445907*^9}, {3.4971671927161283`*^9, 3.497167194198124*^9}, {
   3.497167286656946*^9, 3.497167353074952*^9}, {3.497168153497553*^9, 
   3.497168176491694*^9}, {3.4971699717876368`*^9, 3.497170135414195*^9}, {
   3.4971734308448877`*^9, 3.497173485438511*^9}, {3.49717501224792*^9, 
   3.4971750135173388`*^9}, 3.4971754705456047`*^9, {3.49717555276082*^9, 
   3.497175557945553*^9}, {3.4972732008958883`*^9, 3.497273230323722*^9}}]
},
WindowSize->{1198, 876},
WindowMargins->{{Automatic, 81}, {Automatic, 0}},
FrontEndVersion->"7.0 for Mac OS X x86 (32-bit) (February 18, 2009)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 758, 20, 193, "Input"],
Cell[1306, 42, 16992, 388, 662, "Input"]
}
]
*)

(* End of internal cache information *)
